@@ -123,6 +123,7 @@ sub massageConfig {
             $popup->massageConfig($cfg);
         }
     }
+    return;
 }
 
 =head2 __fixActionCfg
@@ -139,7 +140,8 @@ sub __fixActionCfg {
     my $pkg = ref $self;
     for my $action (@{$self->actionCfg}) {
         next if $action->{action} eq 'separator'
-            or $action->{action} eq 'refresh';
+            or $action->{action} eq 'refresh'
+            or $action->{action} eq 'logout';
         if ($action->{name}) {
             $self->log->warn(
                $pkg . " action should not have a name attribute:"
